@@ -1,5 +1,5 @@
 ## File Name: conf.detect.R
-## File Version: 1.208
+## File Version: 1.211
 
 
 # Confirmatory DETECT analysis
@@ -8,8 +8,8 @@ conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
                 bias_corr=TRUE)
 {
     CALL <- match.call()
-    cat("-----------------------------------------------------------\n" )
-    cat("Confirmatory DETECT Analysis \n" )
+    cat('-----------------------------------------------------------\n' )
+    cat('Confirmatory DETECT Analysis \n' )
     utils::flush.console()
     h1 <- is.matrix(score)
     if (h1){
@@ -17,12 +17,12 @@ conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
     }
     is_one_score <- TRUE
     if (! h1 ){
-        cat("Conditioning on 1 Score\n" )
+        cat('Conditioning on 1 Score\n' )
     } else {
-        cat(paste("Conditioning on ",PP, " Scores\n", sep="") )
+        cat(paste('Conditioning on ',PP, ' Scores\n', sep='') )
         is_one_score <- FALSE
     }
-    cat(paste("Bandwidth Scale:", bwscale, "\n" ) )
+    cat(paste('Bandwidth Scale:', bwscale, '\n' ) )
     utils::flush.console()
     scale_score <- TRUE
     if (!smooth){
@@ -39,7 +39,7 @@ conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
         ccovtable.list <- list()
         args_ccov_np$progress <- FALSE
         for (pp in 1:PP){
-            cat( paste( "DETECT Calculation Score ", pp, "\n", sep="") ) ;
+            cat( paste( 'DETECT Calculation Score ', pp, '\n', sep='') ) ;
             utils::flush.console()
             args_ccov_np$score <- score[,pp]
             ccovtable.list[[pp]] <- do.call( what=ccov.np, args=args_ccov_np)
@@ -48,21 +48,20 @@ conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
                     detect.index( ccovtable, itemcluster=itemcluster ) } )
         detect.matrix <- matrix( unlist( lapply( detect.list, FUN=function( ll){
                                 c( ll[1,], ll[2,], ll[3,] ) } ) ), nrow=PP, byrow=TRUE)
-        detect.summary <- data.frame( "NScores"=PP, "Mean"=colMeans( detect.matrix ),
-                                "SD"=apply( detect.matrix, 2, stats::sd ),
-                                "Min"=apply( detect.matrix, 2, min ),
-                                "Max"=apply( detect.matrix, 2, max ) )
-        rownames(detect.summary) <- c("DETECT Unweighted", "DETECT Weighted",
-                                        "ASSI Unweighted", "ASSI Weighted",
-                                        "RATIO Unweighted", "RATIO Weighted" )
+        detect.summary <- data.frame( NScores=PP, Mean=colMeans( detect.matrix ),
+                                SD=apply( detect.matrix, 2, stats::sd ),
+                                Min=apply( detect.matrix, 2, min ),
+                                Max=apply( detect.matrix, 2, max ) )
+        rownames(detect.summary) <- c('DETECT Unweighted', 'DETECT Weighted',
+                                        'ASSI Unweighted', 'ASSI Weighted',
+                                        'RATIO Unweighted', 'RATIO Weighted' )
     }
-    cat("-----------------------------------------------------------\n" )
+    cat('-----------------------------------------------------------\n' )
     if ( ! h1){
-        res <- list( "detect"=res, "ccovtable"=ccovtable,
-                    "detect.summary"=res )
+        res <- list( detect=res, ccovtable=ccovtable, detect.summary=res )
     } else {
-        res <- list( "detect"=detect.list, "ccovtable"=ccovtable.list,
-            "detect.summary"=detect.summary )
+        res <- list( detect=detect.list, ccovtable=ccovtable.list,
+                        detect.summary=detect.summary )
     }
     res$is_one_score <- is_one_score
     res$CALL <- CALL
@@ -72,7 +71,7 @@ conf.detect <- function( data, score, itemcluster, bwscale=1.1, progress=TRUE,
     #--- print
     print(round(res$detect.summary,3))
     #--- return
-    class(res) <- "conf.detect"
+    class(res) <- 'conf.detect'
     return(res)
 }
 
