@@ -1,5 +1,5 @@
 ## File Name: dexppow.R
-## File Version: 0.04
+## File Version: 0.052
 
 
 ## copied from normalp::dnormp
@@ -10,6 +10,8 @@ dexppow <- function (x, mu=0, sigmap=1, pow=2, log=FALSE)
     expon1 <- (abs(x - mu))^p
     expon2 <- p * sigmap^p
     dsty <- (1/cost) * exp(-expon1/expon2)
-    if (log){ dsty <- log(dsty) }
+    if (log){
+        dsty <- log(dsty)
+    }
     return(dsty)
 }
