@@ -1,5 +1,5 @@
 ## File Name: invariance_alignment_aligned_parameters_summary.R
-## File Version: 0.06
+## File Version: 0.07
 
 invariance_alignment_aligned_parameters_summary <- function(x, label=NULL)
 {
@@ -7,7 +7,7 @@ invariance_alignment_aligned_parameters_summary <- function(x, label=NULL)
                         SD=sirt_colSDs(x=x), Min=sirt_colMins(x=x),
                         Max=sirt_colMaxs(x=x) )
     if ( ! is.null(label) ){
-        colnames(dfr) <- paste0( colnames(dfr), ".", label )
+        colnames(dfr) <- paste0( colnames(dfr), '.', label )
     }
     return(dfr)
 }
