@@ -1,5 +1,5 @@
 ## File Name: linking.haberman.R
-## File Version: 2.647
+## File Version: 2.653
 
 
 #**** Linking Haberman: ETS Research Report 2009
@@ -33,7 +33,7 @@ linking.haberman <- function( itempars, personpars=NULL,
     } else {
         logaM <- aM
     }
-    est_type <- "A (slopes)"
+    est_type <- 'A (slopes)'
     resA <- linking_haberman_als(logaM=logaM, wgtM=wgtM, maxiter=maxiter, conv=conv,
                     progress=progress, est.type=est_type, cutoff=a_trim,
                     reference_value=1-a_log, adjust_main_effects=adjust_main_effects,
@@ -60,12 +60,13 @@ linking.haberman <- function( itempars, personpars=NULL,
     aj_se <- c( NA, res$se )
 
     #**** estimation of B
-    est_type <- "B (intercepts)"
+    est_type <- 'B (intercepts)'
     At_m <- sirt_matrix2( At, nrow=NI)
     bMadj <- bM * At_m
     resB <- linking_haberman_als(logaM=bMadj, wgtM=wgtM, maxiter=maxiter,
                     conv=conv, progress=progress, est.type=est_type,
-                    cutoff=b_trim, reference_value=0, adjust_main_effects=adjust_main_effects,
+                    cutoff=b_trim, reference_value=0,
+                    adjust_main_effects=adjust_main_effects,
                     estimation=estimation, lts_prop=lts_prop, vcov=vcov)
     Bj <- resB$logaj
     Bt <- resB$logaAt
@@ -91,15 +92,15 @@ linking.haberman <- function( itempars, personpars=NULL,
     transf.itempars$se_At <- c( NA, res$se )
 
     #**** tranbsformation for person parameters
-    transf.personpars <- transf.itempars[,c("study","At","se_At2","Bt", "se_Bt")]
+    transf.personpars <- transf.itempars[,c('study','At','se_At2','Bt', 'se_Bt')]
     transf.personpars$At <- transf.pars$At
     transf.personpars$Bt <- -transf.pars$Bt
-    colnames(transf.personpars) <- c("study", "A_theta",
-                "se_A_theta", "B_theta", "se_B_theta" )
-    colnames(transf.itempars) <- c("study", "A_a", "se_A_a",
-                "A_b", "se_A_b", "B_b", "se_B_b" )
+    colnames(transf.personpars) <- c('study', 'A_theta',
+                'se_A_theta', 'B_theta', 'se_B_theta' )
+    colnames(transf.itempars) <- c('study', 'A_a', 'se_A_a',
+                'A_b', 'se_A_b', 'B_b', 'se_B_b' )
     # new item parameters
-    joint.itempars <- data.frame("item"=items, "aj"=aj, "bj"=Bj )
+    joint.itempars <- data.frame('item'=items, 'aj'=aj, 'bj'=Bj )
     # transformations for item parameters
     AtM <- sirt_matrix2( At, nrow=NI)
     BtM <- sirt_matrix2( Bt, nrow=NI)
@@ -111,11 +112,11 @@ linking.haberman <- function( itempars, personpars=NULL,
         for (ll in 1:NS){
             pp0 <- pp1 <- personpars[[ll]]
             pp1 <- transf.personpars$A_theta[ll] * pp1 + transf.personpars$B_theta[ll]
-            ind <- which( substring( colnames(pp0),1,2) %in% c("se", "SE") )
+            ind <- which( substring( colnames(pp0),1,2) %in% c('se', 'SE') )
             if ( length(ind) > 0 ){
                 pp1[,ind] <- transf.personpars$A_theta[ll] * pp0[,ind]
             }
-            ind <- which( substring( colnames(pp0),1,3) %in% c("pid") )
+            ind <- which( substring( colnames(pp0),1,3) %in% c('pid') )
             if ( length(ind) > 0 ){
                 pp1[,ind] <- pp0[,ind]
             }
@@ -128,31 +129,32 @@ linking.haberman <- function( itempars, personpars=NULL,
     # two studies are available.
     selitems <- which( rowSums( 1 - is.na( a.orig ) ) > 1 )
     Rsquared.partial.invariance <- Rsquared.invariance <- c(NA,NA)
-    names(Rsquared.invariance) <- c("slopes", "intercepts" )
-    names(Rsquared.partial.invariance) <- c("slopes", "intercepts" )
+    names(Rsquared.invariance) <- c('slopes', 'intercepts' )
+    names(Rsquared.partial.invariance) <- c('slopes', 'intercepts' )
 
     # retransformed parameters
     aj1 <- aj * AtM
     a.res <- a.orig - aj1
 
-    Rsquared.invariance["slopes"] <- 1 - sirt_sum( a.res[ selitems,]^2 ) / sirt_sum( a.orig[ selitems, ]^2 )
-    Rsquared.partial.invariance["slopes"] <- 1 -
+    Rsquared.invariance['slopes'] <- 1 - sirt_sum( a.res[ selitems,]^2 ) /
+                                            sirt_sum( a.orig[ selitems, ]^2 )
+    Rsquared.partial.invariance['slopes'] <- 1 -
         sirt_sum( a.res[ selitems,]^2 * aj_wgtM[selitems,]  ) /
         sirt_sum( a.orig[ selitems, ]^2 * aj_wgtM[selitems, ]  )
     bj1 <- 1 / AtM *( Bj + BtM )
     b.res <- b.orig - bj1
 
-    Rsquared.partial.invariance["intercepts"] <- 1 -
+    Rsquared.partial.invariance['intercepts'] <- 1 -
         sirt_sum( b.res[ selitems,]^2 * Bj_wgtM[selitems,] ) /
         sirt_sum( b.orig[ selitems, ]^2 * Bj_wgtM[selitems,] )
-    Rsquared.invariance["intercepts"] <- 1 -
+    Rsquared.invariance['intercepts'] <- 1 -
         sirt_sum( b.res[ selitems,]^2  ) / sirt_sum( b.orig[ selitems, ]^2 )
     es.invariance <- rbind( Rsquared.invariance,
             sqrt( 1- Rsquared.invariance ) )
-    rownames(es.invariance) <- c("R2", "sqrtU2")
+    rownames(es.invariance) <- c('R2', 'sqrtU2')
     es.partial.invariance <- rbind( Rsquared.partial.invariance,
             sqrt( 1- Rsquared.partial.invariance ) )
-    rownames(es.partial.invariance) <- c("R2", "sqrtU2")
+    rownames(es.partial.invariance) <- c('R2', 'sqrtU2')
 
     # logical indicating whether item slopes are linked
     linking_slopes <- stats::sd( transf.pars$At ) < 1E-10
@@ -172,7 +174,7 @@ linking.haberman <- function( itempars, personpars=NULL,
             b.item_stat=Bj_item_stat, linking_slopes=linking_slopes,
             description='Linking according to Haberman (2009)',
             res_opt_slopes=resA, res_opt_intercepts=resB, CALL=CALL, time=time )
-    class(res) <- "linking.haberman"
+    class(res) <- 'linking.haberman'
     return(res)
 }
 
