@@ -1,8 +1,9 @@
 ## File Name: lsem.MGM.stepfunctions.R
-## File Version: 0.12
+## File Version: 0.131
 
-##############################################################
-lsem.MGM.stepfunctions <- function( object, moderator.grid ){
+#**** define object with LSEM step functions
+lsem.MGM.stepfunctions <- function( object, moderator.grid )
+{
 
     # object <- lsem.object
     moderator.grouped <- object$moderator.grouped
@@ -12,11 +13,9 @@ lsem.MGM.stepfunctions <- function( object, moderator.grid ){
     G <- length(moderator.grid)
 
     for (gg in 1:G){
-        # gg <- 4
         mod.gg <- moderator.grid[gg]
         ind.gg <- which( ( moderator.grouped$min <=mod.gg ) &
                             ( moderator.grouped$max > mod.gg ) )
-
         grouped.gg <-  object$moderator.grid[ind.gg]
         parameters.gg <- parameters[ parameters$moderator==grouped.gg, ]
         parameters.gg$moderator <- mod.gg
@@ -25,4 +24,3 @@ lsem.MGM.stepfunctions <- function( object, moderator.grid ){
     dfr <- dfr[ order( 10E20*dfr$parindex + dfr$moderator ), ]
     return(dfr)
 }
-##############################################################
