@@ -1,14 +1,14 @@
 ## File Name: lsem_fitsem_verbose_progress.R
-## File Version: 0.02
+## File Version: 0.03
 
 lsem_fitsem_verbose_progress <- function(gg, G, pr, verbose)
 {
     if (verbose){
         if (gg %in% pr ){
-            cat("-")
+            cat('-')
         }
         if (gg>G){
-            cat("|\n")
+            cat('|\n')
         }
         utils::flush.console()
     }
