@@ -1,16 +1,16 @@
 ## File Name: write.format2.R
-## File Version: 1.09
+## File Version: 1.12
 
 
 
-#----------------------------------------------------------------
-# utility function for formatting output in write.fwf2
-write.format2 <- function( vec1, ff, fr ){
+#*** utility function for formatting output in write.fwf2
+write.format2 <- function( vec1, ff, fr )
+{
     if (fr==0){
         vec2 <- round( vec1, fr )
         blank.vv <- paste( rep( " ", ff ), collapse="" )
         vec2 <- paste( substring( blank.vv, 1, ff - nchar(vec2) ), vec2, sep="")
-            } else {
+    } else {
         d.vv <- round( vec1, fr ) + 10^(-(fr+1))
         # generate blank
         blank.vv <- paste( rep( " ", ff+1 ), collapse="" )
@@ -19,9 +19,8 @@ write.format2 <- function( vec1, ff, fr ){
         d.vv[ g.vv  ] <- ifelse( ff > 1,  gsub( "NA", " .", d.vv[g.vv] ), gsub( "NA", ".", d.vv[g.vv] ) )
         vec2 <- substring( d.vv, 1, ff )
         vec2
-            }
-    return(vec2 )
     }
-#---------------------------------------------------------------
+    return(vec2)
+}
 
 .write.format2 <- write.format2
