@@ -1,5 +1,5 @@
 ## File Name: xxirt_nr_grad_fun_Rcpp.R
-## File Version: 0.170
+## File Version: 0.173
 
 xxirt_nr_grad_fun_Rcpp <- function(x, em_args, eps=1e-100)
 {
@@ -11,7 +11,7 @@ xxirt_nr_grad_fun_Rcpp <- function(x, em_args, eps=1e-100)
     eps2 <- 1e-300
 
     grad <- 0*x
-
+    
     #*** compute prior distribution
     prior_Theta0 <- xxirt_compute_prior_Theta_from_x(x=x, em_args=em_args)
 
@@ -31,7 +31,7 @@ xxirt_nr_grad_fun_Rcpp <- function(x, em_args, eps=1e-100)
     probs_items_der <- list()
     ratio_list <- list()
 
-    for (mm in 1:MIGC){
+    for (mm in seq_len(MIGC) ){
         free_pars_design_mm <- free_pars_design[ free_pars_design$item_group_comp==mm, ]
         x1 <- x[ em_args$parindex_items ]
         x1 <- sirt_add_increment(x=x1, pos=free_pars_design_mm$pid, value=h)
@@ -46,7 +46,7 @@ xxirt_nr_grad_fun_Rcpp <- function(x, em_args, eps=1e-100)
     }
 
     #--- loop over item parameters
-    for (pp in 1:NPI){
+    for (pp in seq_len(NPI) ){
 
         free_pars_design_pp <- free_pars_design[pp,]
         partable_pp <- partable[ partable$parlabel==free_pars_design_pp$parlabel, ]
